@@ -28,7 +28,7 @@ class DKConnection():
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
         if response.status_code != 200:
             logger.error("Error Starting Order %s %s %s." % (kitchen, recipe, variation))
-            raise DKOrderException
+            raise DKOrderStartException
         order = json.loads(response.text)
         order_id = order['order_id']
         logger.info(order_id)
